@@ -26,7 +26,7 @@ require 5.004;
 use strict;
 
 use RPC::PlServer 0.2001;
-# require DBI; # deferred till AcceptVersion() to aid threading
+require DBI;
 require Config;
 
 
@@ -526,7 +526,7 @@ UID's can be passed as group names or numeric values.
 
 =item I<version> (B<--version>)
 
-Supresses startup of the server; instead the version string will
+Suppresses startup of the server; instead the version string will
 be printed and the program exits immediately.
 
 =back
@@ -545,7 +545,7 @@ The configuration file is just that of I<RPC::PlServer> or I<Net::Daemon>
 with some additional attributes in the client list.
 
 The config file is a Perl script. At the top of the file you may include
-arbitraty Perl source, for example load drivers at the start (useful
+arbitrary Perl source, for example load drivers at the start (useful
 to enhance performance), prepare a chroot environment and so on.
 
 The important thing is that you finally return a hash ref of option
@@ -604,7 +604,7 @@ every workstation shall be able to execute every query.
 There is a perl program "dbiproxy" which runs on a machine which is able
 to connect to all the databases we wish to reach. All Perl-DBD-drivers must
 be installed on this machine. You can also reach databases for which drivers 
-are not available on the machine where you run the programm querying the 
+are not available on the machine where you run the program querying the 
 database, e.g. ask MS-Access-database from Linux.
 
 Create a configuration file "proxy_oracle.cfg" at the dbproxy-server:
@@ -624,7 +624,7 @@ Create a configuration file "proxy_oracle.cfg" at the dbproxy-server:
 		# hint to organize:
 		# the most specialized rules for single machines/users are 1st
 		# then the denying rules
-		# the the rules about whole networks
+		# then the rules about whole networks
 
 		# rule: internal_webserver
 		# desc: to get statistical information
@@ -651,7 +651,7 @@ Create a configuration file "proxy_oracle.cfg" at the dbproxy-server:
 		},
 
 		# rule: employee_workplace
-		# desc: get detailled informations
+		# desc: get detailed information
 		{
 			# any IP-address is meant here
 			mask => '^10\.95\.81\.(\d+)$',
@@ -687,7 +687,7 @@ Start the proxyserver like this:
 
 =head2 Testing the connection from a remote machine
 
-Call a programm "dbish" from your commandline. I take the machine from rule "internal_webserver"
+Call a program "dbish" from your commandline. I take the machine from rule "internal_webserver"
 
 	dbish "dbi:Proxy:hostname=oracle.zdf;port=12400;dsn=dbi:Oracle:e01" informationdesk xxx
 
@@ -809,7 +809,7 @@ Controlling which person at which machine is allowed to access
 
 =item * "mask" is a perl regular expression against the plain ip-address of the machine which wishes to connect _or_ the reverse-lookup from a nameserver.
 
-=item * "accept" tells the dbiproxy-server wether ip-adresse like in "mask" are allowed to connect or not (0/1)
+=item * "accept" tells the dbiproxy-server whether ip-adresse like in "mask" are allowed to connect or not (0/1)
 
 =item * "users" is a reference to a list of usernames which must be matched, this is NOT a regular expression.
 
@@ -817,7 +817,7 @@ Controlling which person at which machine is allowed to access
 
 Controlling which SQL-statements are allowed
 
-You can put every SQL-statement you like in simply ommiting "sql => ...", but the more important thing is to restrict the connection so that only allowed queries are possible.
+You can put every SQL-statement you like in simply omitting "sql => ...", but the more important thing is to restrict the connection so that only allowed queries are possible.
 
 If you include an sql-section in your config-file like this:
 
@@ -867,6 +867,13 @@ Don't try to put parameters into the sql-query like this:
 =back
 
 
+=head1 SECURITY WARNING
+
+L<RPC::PlServer> used underneath is not secure due to serializing and
+deserializing data with L<Storable> module. Use the proxy driver only in
+trusted environment.
+
+
 =head1 AUTHOR
 
     Copyright (c) 1997    Jochen Wiedmann
